# optax-adan
An implementation of adan optimizer for [optax](https://github.com/deepmind/optax/)

Reference: https://arxiv.org/abs/2208.06677

Collab with usage example can be found [here](https://colab.research.google.com/drive/19--gju3ELQ9qPbDZbE4NmEnGBLJC901x?usp=sharing)
